info = {
    'name': 'arb',
    'version': '1.0.0',
    'description': 'Application Resource Bundle (ARB)',
    'file-mode': "language-file",
    'file-extensions': [ 'arb' ],
    'modifies-existing-files': true,
    'copy-template-defaults': [ 'Localizations.of(context).%1' ],

    configuration: [
        common.configuration[0], // indent
        {
            'name': 'format',
            'displayName': 'Format',
            'type': 'enum',
            'default': 'plaintext-json',
            'values': {
                'plaintext-json': 'ARB JSON format'
            }
        }
    ],

    'formats': common.formats
};


fileio = {

    //
    // Imports file contents
    //
    // filecontent: content of the file as string
    //
    importData: function(filecontent, fileformat)
    {
        if(babeledit.checkAndReportJsonError(filecontent, 0))
        {
            return;
        }

        var data = JSON.parse(filecontent);

        for (var key in data)
        {
            if (typeof data[key] === "string" && !key.startsWith("@"))
            {
                const metaKey = "@" + key;
                var description = "";
                if (metaKey in data && "description" in data[metaKey])
                {
                    description = data[metaKey].description;
                }

                babeledit.addTranslation([ key ], null, data[key], description);
            }
        }
    },

    //
    // prepare writing of files
    //
    prepareExport: function(filename, language, configuration)
    {
        common.prepareExport(filename, language, configuration);
    },


    //
    // save translation for current file
    //
    saveTranslation: function(fullPath, language, translation)
    {
        if(language !== common.languageToExport)
        {
            return;
        }
        var key = fullPath.pop();
        common.documentRoot[key] = translation;
    },

    //
    // return formatted file data
    //
    getSaveFile: function(filecontent)
    {
        var oldData = JSON.parse(filecontent);
        var newData = common.documentRoot;

        // remove translations + metadata which no longer exist from JSON file
        for (var key in oldData)
        {
            if (!key.startsWith("@") && !(key in newData))
            {
                delete oldData[key];
                delete oldData['@' + key];
            }
        }
        // insert translations into existing JSON file
        for (key in newData)
        {
            oldData[key] = newData[key];
        }

        common.documentRoot = oldData;
        return common.getSaveFile();
    }

}
