info = {
    'name': 'vue-sfc',
    'version': '1.0.0',
    'description': 'Vue.js single file component',
    'file-mode': "smartfolder",
    'delimiter': '.',
    'namespace-delimiter': ' - ',
    'file-extensions': [ 'vue' ],
    'copy-template-defaults': [ "$t('%1')" ],
    'copy-without-namespace': true,
    'modifies-existing-files': true,

    'exclude-dirs': ['node_modules', 'vendor', 'dist'],

    'sources-to-scan': ['*.js', '*.vue', '*.html', '*.htm'],
    'sources-to-exclude': [],
    'source-scanner-rx': null, // disable source code references view

    configuration: [
        common.configuration[0], // indent
        {
            'name': 'format',
            'displayName': 'Format',
            'type': 'enum',
            'default': 'namespaced-json',
            'values': {
                'namespaced-json': '<i18n> in Vue single file component'
            }
        },
        common.configuration[2] // array mode
    ],

    'formats': common.formats
};


fileio = {

    //
    // Imports file contents
    //
    // filecontent: content of the file as string
    //
    importData: function(filecontent, fileformat)
    {
        var i18nSplit = /([^]*?<i18n>\s*)([^]*?)(<\/i18n>[^]*)/;
        var fileParts = filecontent.match(i18nSplit);

        if(!fileParts)
        {
            babeledit.setIgnoredFile(true, "&lt;i18n> section is missing in .vue file. Add the section or remove the file from the file list.");
            return;
        }

        if(!fileParts[2].trim())
        {
            // accept empty <i18n> sections without error
            return;
        }

        if(babeledit.checkAndReportJsonError(fileParts[2], (fileParts[1].match(/\n/g) || []).length))
        {
            // error occured and was already reported
            return;
        }

        var data = JSON.parse(fileParts[2]);

        common.formatFlags = common.formats['namespaced-json'].flags;

        for (var lang in data)
        {
            common._recursiveCollectTranslations([], data[lang], lang);
        }
    },

    //
    // prepare writing of files
    //
    prepareExport: function(filename, language, configuration)
    {
        common.prepareExport(filename, language, configuration)
    },


    //
    // save translation for current file
    //
    saveTranslation: function(fullPath, language, translation)
    {
        // TODO remove file system parts from fullPath
        fullPath.unshift(language); // toplevel folder in JSON is language
        var key = fullPath.pop();   // concept name
        var treeNode = common._makePathRecursive(fullPath, common.documentRoot);
        treeNode[key] = translation;
    },

    //
    // return formatted file data
    //
    getSaveFile: function(filecontent)
    {
        var i18nSplit = /([^]*?<i18n>)([^]*?)(<\/i18n>[^]*)/;
        var fileParts = filecontent.match(i18nSplit);

        if(!fileParts)
        {
            babeledit.addError("&lt;i18n> section is missing in .vue file.");
            return filecontent;
        }

        var numCRLF = (filecontent.match(/\r\n/g) || []).length;
        var numLF = (filecontent.match(/\n/g) || []).length - numCRLF;

        var newContent = fileParts[1] + "\n" + common.getSaveFile() + fileParts[3];
        newContent = newContent.replace(/\r\n/g, "\n");
        if (numCRLF > numLF)
        {
            newContent = newContent.replace(/\n/g, "\r\n");
        }

        return newContent;
    }

}
